@@ -46,11 +46,19 @@ renv_bootstrap_download_impl <- function(url, destfile) {
 
 renv_bootstrap_download <- function(version) {
 
-  methods <- list(
-    renv_bootstrap_download_cran_latest,
-    renv_bootstrap_download_cran_archive,
-    renv_bootstrap_download_github
-  )
+  # if the renv version number has 4 components, assume it must
+  # be retrieved via github
+  nv <- numeric_version(version)
+  components <- unclass(nv)[[1]]
+
+  methods <- if (length(components) == 4L) {
+    list(renv_bootstrap_download_github)
+  } else {
+    list(
+      renv_bootstrap_download_cran_latest,
+      renv_bootstrap_download_cran_archive
+    )
+  }
 
   for (method in methods) {
     path <- tryCatch(method(version), error = identity)
@@ -76,7 +84,7 @@ renv_bootstrap_download_cran_latest <- function(version) {
   message("* Downloading renv ", version, " from CRAN ... ", appendLF = FALSE)
 
   info <- tryCatch(
-    download.packages("renv", destdir = tempdir()),
+    download.packages("renv", destdir = tempdir(), quiet = TRUE),
     condition = identity
   )
 
@@ -245,8 +253,8 @@ renv_bootstrap_validate_version <- function(version) {
     paste("renv", loadedversion, sep = "@")
 
   fmt <- paste(
-    "renv %1$s was loaded from project library, but renv %2$s is recorded in lockfile.",
-    "Use `renv::record(\"%3$s\")` to record this version in the lockfile.",
+    "renv %1$s was loaded from project library, but this project is configured to use renv %2$s.",
+    "Use `renv::record(\"%3$s\")` to record renv %1$s in the lockfile.",
     "Use `renv::restore(packages = \"renv\")` to install renv %2$s into the project library.",
     sep = "\n"
   )
