@@ -90,7 +90,7 @@ renv_retrieve_impl <- function(package) {
     # if the requested record already exists in the cache,
     # we'll use that package for install
     cacheable <-
-      settings$use.cache(project = state$project) &&
+      renv_cache_config_enabled(project = state$project) &&
       renv_record_cacheable(record)
 
     if (cacheable) {
@@ -123,18 +123,22 @@ renv_retrieve_impl <- function(package) {
   if (uselatest)
     record <- renv_available_packages_latest(record$Package)
 
-  # try some early shortcut methods
-  shortcuts <- c(
-    renv_retrieve_explicit,
-    renv_retrieve_local,
-    if (!renv_testing())
-      renv_retrieve_libpaths
-  )
+  if (!renv_restore_rebuild_required(record)) {
+
+    # try some early shortcut methods
+    shortcuts <- c(
+      renv_retrieve_explicit,
+      renv_retrieve_local,
+      if (!renv_testing())
+        renv_retrieve_libpaths
+    )
+
+    for (shortcut in shortcuts) {
+      retrieved <- catch(shortcut(record))
+      if (identical(retrieved, TRUE))
+        return(TRUE)
+    }
 
-  for (shortcut in shortcuts) {
-    retrieved <- catch(shortcut(record))
-    if (identical(retrieved, TRUE))
-      return(TRUE)
   }
 
   # time to retrieve -- delegate based on previously-determined source
@@ -296,7 +300,9 @@ renv_retrieve_git <- function(record) {
 
 }
 
-renv_retrieve_local_find <- function(record) {
+renv_retrieve_local_find <- function(record, project = NULL) {
+
+  project <- renv_project_resolve(project)
 
   # packages installed with 'remotes::install_local()' will
   # have a RemoteUrl entry that we can use
@@ -309,7 +315,7 @@ renv_retrieve_local_find <- function(record) {
 
   # otherwise, use the user's local packages
   roots <- c(
-    renv_paths_project("renv/local"),
+    renv_paths_project("renv/local", project = project),
     renv_paths_local()
   )
 
