@@ -35,3 +35,9 @@ test_that("RENV_PATHS_PREFIX is respected", {
   expect_true(startswith(prefix, os))
 
 })
+
+test_that("RENV_PATHS_PREFIX is not normalized", {
+  renv_scope_envvars(RENV_PATHS_PREFIX = ".")
+  renv_paths_init()
+  expect_identical(Sys.getenv("RENV_PATHS_PREFIX"), ".")
+})
